summaryrefslogtreecommitdiff
path: root/source4/include/ntvfs.h
diff options
context:
space:
mode:
Diffstat (limited to 'source4/include/ntvfs.h')
-rw-r--r--source4/include/ntvfs.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/source4/include/ntvfs.h b/source4/include/ntvfs.h
index 6628402a97..88122166ee 100644
--- a/source4/include/ntvfs.h
+++ b/source4/include/ntvfs.h
@@ -75,8 +75,11 @@ struct ntvfs_ops {
/* printing specific operations */
NTSTATUS (*lpq)(struct request_context *req, union smb_lpq *lpq);
/* trans interfaces - only used by CIFS backend to prover complete passthru for testing */
NTSTATUS (*trans2)(struct request_context *req, struct smb_trans2 *trans2);
+
+ /* trans interface - used by IPC backend for pipes and RAP calls */
+ NTSTATUS (*trans)(struct request_context *req, struct smb_trans2 *trans);
};
@@ -75,8 +75,11 @@ struct ntvfs_ops {
/* printing specific operations */
NTSTATUS (*lpq)(struct request_context *req, union smb_lpq *lpq);
- /* trans interfaces - only used by CIFS backend to prover complete passthru for testing */
+ /* trans2 interface - only used by CIFS backend to prover complete passthru for testing */
NTSTATUS (*trans2)(struct request_context *req, struct smb_trans2 *trans2);